//***************************************************************************
//* LANIOライブラリ ヘッダファイル
//***************************************************************************

#ifdef _WINDOWS
#ifdef EXPORT_DECLSPEC
#define DECLSPEC extern "C" __declspec(dllexport) int __stdcall
#else
#define DECLSPEC extern "C" __declspec(dllimport) int __stdcall
#endif
#else
#define DECLSPEC int
typedef int BOOL;
#endif

//***************************************************************************
//* 型定義、定数定義
//***************************************************************************

//***************************************************************************
//* LANIOハンドラ
//***************************************************************************
#define hLANIO int

//***************************************************************************
//* LELanioGetLastErrorが返すエラーコード
//***************************************************************************
enum LANIOERROR {
	LELANIOERR_NOINIT = 1,			//* 初期化されていません。LELanioInitを実行してください。
	LELANIOERR_NOLANIO,				//* 検索した結果、LANIOが発見できませんでした。
	LELANIOERR_NOTEXIST,			//* 検索で発見したLANIOより多い値を指定しました。
	LELANIOERR_NOTFOUND,			//* 指定された条件のLANIOを発見できませんでした。
	LELANIOERR_NOCONNECTED,			//* LANIOと接続していません。LELanioConnectを実行してください。
	LELANIOERR_INVALIDOPERATION,	//* 指定された操作は実行できません。
	LELANIOERR_ALREADY_CONNECTED,	//* すでに接続しています。
	LELANIOERR_OVERCONNECTMAX,		//* 接続最大数を超過しました。
	LELANIOERR_INVALIDRETURNVALUE,	//* 不正な戻り値が返りました。
};

//***************************************************************************
//* LELanioGetModelで取得するLANIOモデル
//***************************************************************************
enum LANIOMODEL {
	LA2R3PP = 0,
	LA3R2P  = 1,		// LA-3R2P-P含む
	LA7P    = 2,		// LA-7P-P / LA-7P-A含む
	LA5R    = 3,
	LA5T2S  = 4,		// LA-5T2S-P含む
	LA5PP   = 5,
	LA3R3PP = 6,
	LA232R  = 7,
	LA232T  = 8,
	LA485R  = 9,
	LA485T  = 10,
	LA4R4PP = 16+1,
	LA8R    = 16+3,
	LA8T    = 16+4,
	LA8PP   = 16+5,
	LA4T4SP = 16+6,
	LAN2R2P = 16+9,
	LA2R3A  = 32+8,
	LA2A3PP = 32+9,
	LA2R3AV2= 32+10,
	LA3A2PP = 32+11,
	LA5AI   = 32+12,
	NO_GETMODEL = -1,
};

//***************************************************************************
//* LELanioSetDisconnectionTime で用いる無通信時切断時間の定義
//***************************************************************************
enum LELANIO_DISCONTIME{
	LELANIO_DISCONTIME_0msec    = 0, // すぐに切断
	LELANIO_DISCONTIME_300msec  = 1,
	LELANIO_DISCONTIME_500msec  = 2,
	LELANIO_DISCONTIME_1sec     = 3,
	LELANIO_DISCONTIME_3sec     = 4,
	LELANIO_DISCONTIME_5sec     = 5,
	LELANIO_DISCONTIME_10sec    = 6,
	LELANIO_DISCONTIME_30sec    = 7,
	LELANIO_DISCONTIME_50sec    = 8,
	LELANIO_DISCONTIME_1min     = 9,
	LELANIO_DISCONTIME_3min     = 10,
	LELANIO_DISCONTIME_5min     = 11,
	LELANIO_DISCONTIME_10min    = 12,
	LELANIO_DISCONTIME_30min    = 13,
	LELANIO_DISCONTIME_50min    = 14,
	LELANIO_DISCONTIME_NONE     = 15, // 切断なし(無制限)
};

//***************************************************************************
//* LELanioSetNoticeTime で用いるデジタル入力定期通知時間の定義
//***************************************************************************
enum LELANIO_DI_NOTICETIME{
	LELANIO_DI_NOTICETIME_NONE  = 0, // 定期通知なし
	LELANIO_DI_NOTICETIME_10sec = 1,
	LELANIO_DI_NOTICETIME_30sec = 2,
	LELANIO_DI_NOTICETIME_1min  = 3,
	LELANIO_DI_NOTICETIME_3min  = 4,
};

//***************************************************************************
//* LELanioPulseModeSetConfig で用いるパルスカウント測定ウィンドウ幅の定義
//***************************************************************************
enum LELANIO_PULSE_WINDOW{
	LELANIO_PULSE_WINDOW_STARTSTOP = 0, // 手動 START-STOP
	LELANIO_PULSE_WINDOW_100msec   = 1,
	LELANIO_PULSE_WINDOW_1sec      = 2,
	LELANIO_PULSE_WINDOW_10sec     = 3, 
};

//***************************************************************************
//* LELanioSetResetTime で用いる8点タイプLANIO の無通信時リセット時間の定義
//***************************************************************************
enum LELANIO_RESETTIME{
	LELANIO_RESETTIME_NONE   = 0,  // リセット動作解除
    LELANIO_RESETTIME_5sec   = 1,
	LELANIO_RESETTIME_10sec  = 2,
	LELANIO_RESETTIME_20sec  = 3,
	LELANIO_RESETTIME_30sec  = 4,
	LELANIO_RESETTIME_1min   = 5,
	LELANIO_RESETTIME_2min   = 6,
	LELANIO_RESETTIME_5min   = 7,
	LELANIO_RESETTIME_10min  = 8,
	LELANIO_RESETTIME_20min  = 9,
	LELANIO_RESETTIME_30min  = 10,
};

//***************************************************************************
//* アナログ入力モデルの入力レンジの定義
//***************************************************************************
enum LELANIO_AI_RANGE {
	LELANIO_AI_RANGE_100mV          = 0,
	LELANIO_AI_RANGE_1V             = 1,
	LELANIO_AI_RANGE_10V            = 2,
	LELANIO_AI_RANGE_30V            = 3,
	LELANIO_AI_RANGE_20mA_250ohm    = 4,
	LELANIO_AI_RANGE_20mA_50ohm     = 5,
	LELANIO_AI_RANGE_TC             = 6, // 熱電対
};

//***************************************************************************
//* アナログ入力モデルの熱電対タイプ定義
//***************************************************************************
enum LELANIO_AI_TCTYPE {
	LELANIO_AI_TCTYPE_K             = 0,
	LELANIO_AI_TCTYPE_J             = 1,
	LELANIO_AI_TCTYPE_T             = 2,
	LELANIO_AI_TCTYPE_E             = 3,
	LELANIO_AI_TCTYPE_N             = 4,
	LELANIO_AI_TCTYPE_R             = 5,
	LELANIO_AI_TCTYPE_S             = 6,
	LELANIO_AI_TCTYPE_B             = 7,
};

//***************************************************************************
//* アナログ入力モデル内蔵ADCサンプリング速度の定義
//***************************************************************************
enum LELANIO_AI_ADCSPS {
	LELANIO_AI_ADCSPS_10     = 0,  // 10sps
	LELANIO_AI_ADCSPS_16_6   = 1,  // 16.6sps
	LELANIO_AI_ADCSPS_50     = 2,  // 50sps
	LELANIO_AI_ADCSPS_60     = 3,  // 60sps
	LELANIO_AI_ADCSPS_400    = 4,  // 400sps
	LELANIO_AI_ADCSPS_1200   = 5,  // 1200sps
	LELANIO_AI_ADCSPS_3600   = 6,  // 3600sps
	LELANIO_AI_ADCSPS_14400  = 7,  // 14400sps	
};

//***************************************************************************
//* アナログ入力モデル専用の周期転送時間の定義
//***************************************************************************
enum LELANIO_AI_TRANSMITCYCLE {
	LELANIO_AI_TRANSMITCYCLE_50msec  = 0,
	LELANIO_AI_TRANSMITCYCLE_100msec = 1,
	LELANIO_AI_TRANSMITCYCLE_200msec = 2,
	LELANIO_AI_TRANSMITCYCLE_500msec = 3,
	LELANIO_AI_TRANSMITCYCLE_1sec    = 4,
	LELANIO_AI_TRANSMITCYCLE_2sec    = 5,
	LELANIO_AI_TRANSMITCYCLE_5sec    = 6,
	LELANIO_AI_TRANSMITCYCLE_10sec   = 7,
	LELANIO_AI_TRANSMITCYCLE_20sec   = 8,
	LELANIO_AI_TRANSMITCYCLE_30sec   = 9,
	LELANIO_AI_TRANSMITCYCLE_1min    = 10,
	LELANIO_AI_TRANSMITCYCLE_2min    = 11,
	LELANIO_AI_TRANSMITCYCLE_5min    = 12,
	LELANIO_AI_TRANSMITCYCLE_10min   = 13,
};

//***************************************************************************
//* アナログ出力モデルの出力レンジの定義
//***************************************************************************
enum LELANIO_AO_RANGE {
	LELANIO_AO_RANGE_10V             = 0,
	LELANIO_AO_RANGE_20mA            = 1,
};

//***************************************************************************
//* アナログモデルを対向で使用して温度伝送を行う際の出力レンジ定義
//***************************************************************************
enum LELANIO_TC_TRANSMITRANGE {
	LELANIO_TC_TRANSMITRANGE_0_10V   = 0, // 0-10 V
	LELANIO_TC_TRANSMITRANGE_0_5V    = 1, // 0-5 V
	LELANIO_TC_TRANSMITRANGE_1_5V    = 2, // 1-5 V
	LELANIO_TC_TRANSMITRANGE_4_20mA  = 3, // 4-20 mA
};

//***************************************************************************
//* 初期化、終了、エラー取得関数
//***************************************************************************

//***************************************************************************
//*		LANIOライブラリを初期化します。
//***************************************************************************
DECLSPEC LELanioInit();

//***************************************************************************
//*		LANIOライブラリの使用を終了します。
//***************************************************************************
DECLSPEC LELanioEnd();

//***************************************************************************
//*		直前に発生したエラー番号を取得します。
//*		戻り値 : エラーの情報を返します
//***************************************************************************
DECLSPEC LELanioGetLastError();

//***************************************************************************
//*複数のネットワークデバイスがあるとき、使用するデバイスを選択します
//*引数   : ipaddress  使用するデバイスのIPアドレス
//***************************************************************************
DECLSPEC LELanioSelectNetworkDevice(char *ipaddress);

//***************************************************************************
//* LANIO検索関数
//***************************************************************************

//***************************************************************************
//*		自動的にLANIOのIDとModelを取得する機能についての設定をします。
//*		引数   : enable  この機能を使用する場合はTRUE(1)、しない場合はFALSE(0)
//*		         port    IDとModelを自動取得するシリアルのポート番号
//***************************************************************************
DECLSPEC LELanioSetAutoRequestIdModel(BOOL enable, int port);

//***************************************************************************
//*		LAN内にあるLANIOを検索します。
//*		引数   : msec    タイムアウト時間（単位 m秒）
//*		戻り値 : 発見したLANIOの数。発見できなかった場合は0。エラー時は-1
//***************************************************************************
DECLSPEC LELanioSearch(int msec);

//***************************************************************************
//* LANIO情報取得関数
//***************************************************************************

//***************************************************************************
//*		検索したLANIOのIPアドレスを取得します。
//*		引数   : lanio       LANIO番号
//*		         ipaddress   IPアドレスを取得するバッファへのポインタ(16byte必要)
//***************************************************************************
DECLSPEC LELanioGetIpAddress(int lanio, char *ipaddress);

//***************************************************************************
//*		検索したLANIOのMACアドレスを取得します。
//*		引数   : lanio       LANIO番号
//*		         macaddress  MACアドレスを取得するバッファへのポインタ(6byte必要)
//***************************************************************************
DECLSPEC LELanioGetMacAddress(int lanio, unsigned char *macaddress);

//***************************************************************************
//*		LANIOのID番号を取得します。
//*		引数   : lanio   LANIO番号
//*		         id      LANIOのIDを取得するバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetId(int lanio, int *id);

//***************************************************************************
//*		LANIOのモデルを取得します。
//*		引数   : lanio   LANIO番号
//*		         model   LANIOのモデルを取得するバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetModel(int lanio, int *model);

//***************************************************************************
//*		検索したLANIOに対してIDとモデル番号を質問します。
//*		引数   : lanio   LANIO番号
//*		         id      LANIOのIDを取得するバッファへのポインタ
//*		         model   LANIOのモデルを取得するバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioRequestIdModel(int lanio, int *id, int *model);

//***************************************************************************
//* LANIO接続関数
//***************************************************************************

//***************************************************************************
//*		LELanioSearchによって発見された順番を指定して接続します。
//*		引数   : lanio   LANIO番号
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnect(int lanio);

//***************************************************************************
//*		IDとモデルを指定して接続します。
//*		引数   : id      LANIOのID番号
//*		         model   LANIOのモデル
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnectByIdModel(int id, int model);

//***************************************************************************
//*		IPアドレスを指定して接続します。
//*		引数   : ipaddress   IPアドレス文字列バッファへのポインタ
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnectByIpAddress(char *ipaddress);

//***************************************************************************
//*		MACアドレスを指定して接続します。
//*		引数   : macaddress  MACアドレスバッファへのポインタ
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnectByMacAddress(unsigned char *macaddress);

//***************************************************************************
//*		IPアドレスもしくはURLを指定して接続します。
//*		引数   : address IPアドレスまたはurl文字列バッファへのポインタ
//*		         msec    タイムアウト時間（単位 m秒）
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnectDirect(char *address, int msec);

//***************************************************************************
//*		IPアドレスもしくはURL、ポート番号を指定して接続します。接続時にUDPを使用しません。
//*		引数   : address    IPアドレスまたはurl文字列バッファへのポインタ
//*		         msec       タイムアウト時間（単位 m秒）
//*		         serialport ポート番号
//*		戻り値 : エラー時は-1、正常終了時はLANIO操作ハンドルを返します
//***************************************************************************
DECLSPEC LELanioConnectDirect2(char *address, int msec, int serialport);

//***************************************************************************
//* LANIO切断関数
//***************************************************************************

//***************************************************************************
//*		LANIOとの接続を切断します。
//*		引数   : handle  LANIO操作ハンドル
//***************************************************************************
DECLSPEC LELanioClose(hLANIO handle);

//***************************************************************************
//* 入出力関数
//***************************************************************************

//***************************************************************************
//*		LANIOのDOを操作します。一点単位の操作に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         pio     操作するDOポート番号。DO1=0、DO2=1...
//*		         active  ONなら1、OFFなら0
//***************************************************************************
DECLSPEC LELanioOutPio(hLANIO handle, int pio, BOOL active);

//***************************************************************************
//*		LANIOのDOを操作します。全てのDOに対し一斉に操作する時に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         piobit  DOポートの設定。最下位ビットからDO1、DO2...に対応します
//***************************************************************************
DECLSPEC LELanioOutPioAll(hLANIO handle, int piobit);

//***************************************************************************
//*		LANIOのDIを取得します。一点単位の取得に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         pio     取得するDIポート番号。DI1=0、DI2=1...に対応します
//*		         active  ONなら1、OFFなら0が入るバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioInPio(hLANIO handle, int pio, BOOL *active);

//***************************************************************************
//*		LANIOのDIを取得します。全てのDIに対し一斉に取得する時に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         piobit  DIポートの内容が入るバッファへのポインタ
//*		                 最下位ビットからDI1、DI2...
//***************************************************************************
DECLSPEC LELanioInPioAll(hLANIO handle, int *piobit);

//***************************************************************************
//*		LANIOの現在のDO状態を取得します。一点単位の取得に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         pio     取得するDOポート番号。DO1=0、DO2=1...に対応します
//*		         active  ONなら1、OFFなら0が入るバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetOut(hLANIO handle, int pio, BOOL *active);

//***************************************************************************
//*		LANIOの現在のDO状態を取得します。全てのDOに対し一斉に取得する時に使用します。
//*		引数   : handle  LANIO操作ハンドル
//*		         piobit  DOポートの内容が入るバッファへのポインタ
//*		                 最下位ビットからDO1、DO2...
//***************************************************************************
DECLSPEC LELanioGetOutAll(hLANIO handle, int *piobit);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFの開始/停止を行います
//*		引数   : handle  LANIO操作ハンドル
//*		         active  自動ON/OFFを開始する=0以外、停止する=0
//***************************************************************************
DECLSPEC LELanioSetAutoSwitchingActive(hLANIO handle, BOOL active);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFの開始/停止設定を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         active  自動ON/OFF状態が入るバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetAutoSwitchingActive(hLANIO handle, BOOL *active);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFの周期を設定します
//*		引数   : handle  LANIO操作ハンドル
//*		         msec    周期（単位 m秒）
//***************************************************************************
DECLSPEC LELanioSetAutoSwitchingTime(hLANIO handle, int msec);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFの周期設定を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         msec    周期（単位 m秒）が入るバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetAutoSwitchingTime(hLANIO handle, int *msec);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFを行うDOを設定します。
//*		引数   : handle  LANIO操作ハンドル
//*		         autoswdo 最下位ビットより、DO1～DO5で自動ON/OFFを行う端子が1
//***************************************************************************
DECLSPEC LELanioSetAutoSwitchingPio(hLANIO handle, int autoswdo);

//***************************************************************************
//*		LANIOの出力端子自動ON/OFFを行うDO設定を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         autoswdo 自動ON/OFF実行DO設定を取得するバッファへのポインタ
//***************************************************************************
DECLSPEC LELanioGetAutoSwitchingPio(hLANIO handle, int *autoswdo);

//***************************************************************************
//*8点タイプLANIOの出力端子自動ON/OFFのチャンネル個別周期を設定します
//*引数   : handle   LANIO操作ハンドル
//*         pio      設定するDOポート番号。DO1=0、DO2=1...に対応します
//*         msec_on  ON時間（100msec単位、設定範囲1-25500）
//*         msec_off OFF時間（100msec単位、設定範囲1-25500）
//***************************************************************************
DECLSPEC LELanioSetAutoSwitchingChannel(hLANIO handle, int pio, int msec_on, int msec_off);

//***************************************************************************
//*8点タイプLANIOの出力端子自動ON/OFFのチャンネル個別周期設定を取得します
//*引数   : handle   LANIO操作ハンドル
//*         pio      取得するDOポート番号。DO1=0、DO2=1...に対応します
//*         msec_on  ON時間（100msec単位）
//*         msec_off OFF時間（100msec単位）
//***************************************************************************
DECLSPEC LELanioGetAutoSwitchingChannel(hLANIO handle, int pio, int *msec_on, int *msec_off);

//***************************************************************************
//*		LANIOの無通信状態になった後の接続維持時間を設定する
//*		引数   : handle  LANIO操作ハンドル
//*		         time    時間
//*		                 0x00:すぐ切断 0x04: 3sec  0x08:50sec  0x0c:10min
//*		                 0x01:300ms    0x05: 5sec  0x09: 1min  0x0d:30min
//*		                 0x02:500ms    0x06:10sec  0x0a: 3min  0x0e:50min
//*		                 0x03: 1sec    0x07:30sec  0x0b: 5min  0x0f:無制限
//***************************************************************************
DECLSPEC LELanioSetDisconnectionTime(hLANIO handle, int time);

//***************************************************************************
//*		LANIOの無通信状態になった後の接続維持時間を取得する
//*		引数   : handle  LANIO操作ハンドル
//*		         time    時間を取得するバッファへのポインタ
//*		                 0x00:すぐ切断 0x04: 3sec  0x08:50sec  0x0c:10min
//*		                 0x01:300ms    0x05: 5sec  0x09: 1min  0x0d:30min
//*		                 0x02:500ms    0x06:10sec  0x0a: 3min  0x0e:50min
//*		                 0x03: 1sec    0x07:30sec  0x0b: 5min  0x0f:無制限
//***************************************************************************
DECLSPEC LELanioGetDisconnectionTime(hLANIO handle, int *time);

//***************************************************************************
//*		LANIOの定期通知時間を設定する
//*		引数   : handle  LANIO操作ハンドル
//*		                 0x00:通知なし 0x04: 3min     0x08:設定禁止  0x0c:設定禁止
//*		                 0x01:10sec    0x05:設定禁止  0x09:設定禁止  0x0d:設定禁止
//*		                 0x02:30sec    0x06:設定禁止  0x0a:設定禁止  0x0e:設定禁止
//*		                 0x03:60sec    0x07:設定禁止  0x0b:設定禁止  0x0f:設定禁止
//***************************************************************************
DECLSPEC LELanioSetNoticeTime(hLANIO handle, int time);

//***************************************************************************
//*		LANIOの定期通知時間を取得する
//*		引数   : handle  LANIO操作ハンドル
//*		                 0x00:通知なし 0x04: 3min   0x08:  ---   0x0c:  ---
//*		                 0x01:10sec    0x05:  ---   0x09:  ---   0x0d:  ---
//*		                 0x02:30sec    0x06:  ---   0x0a:  ---   0x0e:  ---
//*		                 0x03:60sec    0x07:  ---   0x0b:  ---   0x0f:  ---
//***************************************************************************
DECLSPEC LELanioGetNoticeTime(hLANIO handle, int *time);

//***************************************************************************
//*		LANIOのチャタリング判定の基準時間を設定する
//*		引数   : handle  LANIO操作ハンドル
//*		         time    時間(ms単位 4ms～20ms）
//***************************************************************************
DECLSPEC LELanioSetDiDetectTime(hLANIO handle, int time);

//***************************************************************************
//*		LANIOのチャタリング判定の基準時間を取得する
//*		引数   : handle  LANIO操作ハンドル
//*		         time    時間を取得するバッファへのポインタ(ms単位 4ms～20ms）
//***************************************************************************
DECLSPEC LELanioGetDiDetectTime(hLANIO handle, int *time);

//***************************************************************************
//*		LANIOのメールアラートを実行する入力端子を設定します
//*		引数   : handle  LANIO操作ハンドル
//*		         enable  メールアラートを実行するビットを1で指定
//*		                 最下位ビットからDI1、DI2...
//***************************************************************************
DECLSPEC LELanioSetDiMailEnable(hLANIO handle, int enable);

//***************************************************************************
//*		LANIOのメールアラートを実行する入力端子を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         enable  メールアラートを実行するビットを1で指定
//*		                 最下位ビットからDI1、DI2...
//***************************************************************************
DECLSPEC LELanioGetDiMailEnable(hLANIO handle, int *enable);

//***************************************************************************
//*		LANIOのメールアラートを実行する論理状態を設定します
//*		引数   : handle  LANIO操作ハンドル
//*		         logic   HIでメールアラートを実行するビットを1で指定
//*		                 最下位ビットからDI1、DI2...
//***************************************************************************
DECLSPEC LELanioSetDiMailLogic(hLANIO handle, int logic);

//***************************************************************************
//*		LANIOのメールアラートを実行する論理状態を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         logic   HIでメールアラートを実行するビットを1で指定
//*		                 最下位ビットからDI1、DI2...
//***************************************************************************
DECLSPEC LELanioGetDiMailLogic(hLANIO handle, int *logic);

//***************************************************************************
//*		PulseModeに入ります
//*		引数   : handle  LANIO操作ハンドル
//***************************************************************************
DECLSPEC LELanioPulseModeOn(hLANIO handle);

//***************************************************************************
//*		PulseModeを終了します
//*		引数   : handle  LANIO操作ハンドル
//***************************************************************************
DECLSPEC LELanioPulseModeOff(hLANIO handle);

//***************************************************************************
//*		PulseMode状態を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         mode    PulseMode状態。モード中なら1、モード中でなければ0
//***************************************************************************
DECLSPEC LELanioPulseModeGetState(hLANIO handle, int *mode);

//***************************************************************************
//*		PulseModeのパルス数を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         value   パルス数。オーバーフロー状態の場合-1
//***************************************************************************
DECLSPEC LELanioPulseModeGetCount(hLANIO handle, int *value);

//***************************************************************************
//*		PulseModeの設定をします
//*		引数   : handle  LANIO操作ハンドル
//*		         pio     操作するDIポート番号。DI1=0、DI2=1...
//*		         edge    0で立ち上がり、1で立ち下がりエッジ
//*		         time    測定時間
//*		                 0:START-STOP  1:100msec  2:1sec  3:10sec
//*		         chatter チャタリング抑制
//*		                 0:なし  1～3:設定不可  4～20:4～20msec
//***************************************************************************
DECLSPEC LELanioPulseModeSetConfig(hLANIO handle, int pio, BOOL edge, int time, int chatter);

//***************************************************************************
//*		PulseModeの設定を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         pio     操作するDIポート番号。DI1=0、DI2=1...
//*		         edge    0で立ち上がり、1で立ち下がりエッジ
//*		         time    測定時間
//*		                 0:START-STOP  1:100msec  2:1sec  3:10sec
//*		         chatter チャタリング抑制
//*		                 0:なし  1～3:設定不可  4～20:4～20msec
//***************************************************************************
DECLSPEC LELanioPulseModeGetConfig(hLANIO handle, int *pio, BOOL *edge, int *time, int *chatter);

//***************************************************************************
//*		パルス連続測定を開始します
//*		引数   : handle  LANIO操作ハンドル
//***************************************************************************
DECLSPEC LELanioPulseModeContinuesOn(hLANIO handle);

//***************************************************************************
//*		パルス連続測定を終了します
//*		引数   : handle  LANIO操作ハンドル
//***************************************************************************
DECLSPEC LELanioPulseModeContinuesOff(hLANIO handle);

//***************************************************************************
//*		パルス連続測定状態を取得します
//*		引数   : handle  LANIO操作ハンドル
//*		         mode    パルス連続測定状態中なら1、でなければ0
//***************************************************************************
DECLSPEC LELanioPulseModeContinuesGetState(hLANIO handle, int *mode);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeの共通部分設定をします
//*引数   : handle  LANIO操作ハンドル
//*         time    測定時間
//*                 0:START-STOP  1:100msec  2:1sec  3:10sec
//*         chatter チャタリング抑制
//*                 0:なし  1～3:設定不可  4～20:4～20msec
//***************************************************************************
DECLSPEC LELanioPulseModeSetConfig2(hLANIO handle, int time, int chatter);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeの共通部分設定を取得します
//*引数   : handle  LANIO操作ハンドル
//*         time    測定時間
//*                 0:START-STOP  1:100msec  2:1sec  3:10sec
//*         chatter チャタリング抑制
//*                 0:なし  1～3:設定不可  4～20:4～20msec
//***************************************************************************
DECLSPEC LELanioPulseModeGetConfig2(hLANIO handle, int *time, int *chatter);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeのDI部分設定をします
//*引数   : handle  LANIO操作ハンドル
//*         pio     操作するDIポート番号。DI1=0、DI2=1...
//*         enable  1でカウント有効
//*         edge    0で立ち上がり、1で立ち下がりエッジ
//***************************************************************************
DECLSPEC LELanioPulseModeSetConfigChannel(hLANIO handle, int pio, BOOL enable, BOOL edge);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeのDI部分設定を取得します
//*引数   : handle  LANIO操作ハンドル
//*         pio     操作するDIポート番号。DI1=0、DI2=1...
//*         enable  1でカウント有効
//*         edge    0で立ち上がり、1で立ち下がりエッジ
//***************************************************************************
DECLSPEC LELanioPulseModeGetConfigChannel(hLANIO handle, int pio, BOOL *enable, BOOL *edge);

//***************************************************************************
//*無線タイプLANIOの拡張PulseModeのメールアラート設定をします
//*引数   : handle    LANIO操作ハンドル
//*         pio       メールアラート判定を行うDIポート番号。DI1=0、DI2=1...
//*         condition 判定条件 0:メールアラートしない 1:設定値より小さい 2:設定値と一致 3:設定値より大きい
//*         val       判定設定値
//***************************************************************************
DECLSPEC LELanioPulseModeSetAlart(hLANIO handle, int pio, int condition, unsigned long val);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeのメールアラート設定を取得します
//*引数   : handle    LANIO操作ハンドル
//*         pio       メールアラート判定を行うDIポート番号。DI1=0、DI2=1...
//*         condition 判定条件 0:メールアラートしない 1:設定値より小さい 2:設定値と一致 3:設定値より大きい
//*         val       判定設定値
//***************************************************************************
DECLSPEC LELanioPulseModeGetAlart(hLANIO handle, int *pio, int *condition, unsigned long *val);

//***************************************************************************
//*無線タイプ・8点タイプLANIOの拡張PulseModeのパルス数を取得します
//*引数   : handle  LANIO操作ハンドル
//*         pio     操作するDIポート番号。DI1=0、DI2=1...
//*         val     パルス数。オーバーフロー状態の場合FFFFFFFF
//***************************************************************************
DECLSPEC LELanioPulseModeGetCount2(hLANIO handle, int pio, unsigned long *val);

//***************************************************************************
//*8点タイプLANIOの無通信時リセットの設定をします。
//*引数   : handle    LANIO操作ハンドル
//*         resettime 無通信時にリセットする時間設定
//*                   0:自動リセット動作解除  1:5秒  2:10秒  3:20秒  4:30秒
//*                   5:1分  6:2分  7:5分  8:10分  9:20分  10:30分
//***************************************************************************
DECLSPEC LELanioSetResetTime(hLANIO handle, int resettime);

//***************************************************************************
//*アナログ出力の値をDAC内部値で指定して出力します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         range     出力レンジ
//*                   0: 電圧(-10〜+10V) 1: 電流(0〜+20mA)
//*         val       設定するDAC 内部値
//*                   電圧出力時 -32768 〜 32767
//*                   電流出力時      0 〜 32767
//***************************************************************************
DECLSPEC LELanioSetAnalogOutput(hLANIO handle, int ch, int range, int val);

//***************************************************************************
//*複数chのアナログ出力の値をDAC内部値で指定して出力します。
//*引数   : handle    LANIO操作ハンドル
//*         count     操作するAOポートの数
//*         ch        対象とするAO ポートを指定する配列 (AO1 = 0, AO2 = 1, ...)
//*         range     出力レンジを指定する配列
//*                   0: 電圧(-10〜+10V) 1: 電流(0〜+20mA)
//*         val       設定するDAC 内部値の配列
//*                   電圧出力時 -32768 〜 32767
//*                   電流出力時      0 〜 32767
//***************************************************************************
DECLSPEC LELanioSetAnalogOutputMulti(hLANIO handle, int count, int *ch, int *range, int *val);

//***************************************************************************
//*アナログ出力設定の現在値をDAC内部値で取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         range     出力レンジを取得する変数のポインタ
//*                   0: 電圧(-10〜+10V) 1: 電流(0〜+20mA)
//*         val       DAC 内部設定値を取得する変数のポインタ
//*                   電圧出力時 -32768 〜 32767
//*                   電流出力時      0 〜 32767
//***************************************************************************
DECLSPEC LELanioGetAnalogOutput(hLANIO handle, int ch, int *range, int *val);

//***************************************************************************
//*アナログ出力の値を電圧値で指定して出力します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         voltage   設定する電圧値(V) -10.0 〜 +10.0 が有効
//***************************************************************************
DECLSPEC LELanioSetAnalogOutputVoltage(hLANIO handle, int ch, double voltage);

//***************************************************************************
//*アナログ出力の値を電流値で指定して出力します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         mampere   設定する電流値(mA) 0.0 〜 +20.0 が有効
//***************************************************************************
DECLSPEC LELanioSetAnalogOutputCurrent(hLANIO handle, int ch, double mampere);

//***************************************************************************
//*アナログ出力設定の現在値を実値で取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         range     出力レンジを取得する変数のポインタ
//*                   0: 電圧(-10〜+10V) 1: 電流(0〜+20mA)
//*         val       出力設定値を取得する変数のポインタ
//*                   電圧出力時 -10.0 〜 +10.0 (V単位)
//*                   電流出力時     0 〜 +20.0 (mA単位)
//***************************************************************************
DECLSPEC LELanioGetAnalogOutputByValue(hLANIO handle, int ch, int *range, double *val);

//***************************************************************************
//*アナログ出力の起動時初期値をDAC内部値で指定します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         range     出力レンジ
//*                   0: 電圧(-10〜+10V) 1: 電流(0〜+20mA)
//*         val       設定するDAC 内部値
//*                   電圧出力時 -32768 〜 32767
//*                   電流出力時      0 〜 32767
//***************************************************************************
DECLSPEC LELanioSetInitialAnalogOutput(hLANIO handle, int ch, int range, int val);

//***************************************************************************
//*アナログ出力の起動時初期値を電圧値で指定します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         voltage   設定する電圧値(V) -10.0 〜 +10.0 が有効
//***************************************************************************
DECLSPEC LELanioSetInitialAnalogOutputVoltage(hLANIO handle, int ch, double voltage);

//***************************************************************************
//*アナログ出力の起動時初期値を電流値で指定します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAO ポートの指定(AO1 = 0, AO2 = 1, ...)
//*         mampere   設定する電流値(mA) 0.0 〜 +20.0 が有効
//***************************************************************************
DECLSPEC LELanioSetInitialAnalogOutputCurrent(hLANIO handle, int ch, double mampere);

//***************************************************************************
//*アナログ入力の現在値をADC値で取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         val       ADC 値を取得する変数のポインタ
//*                   現在の入力レンジが
//*                     電圧時は-8388608 〜 +8388607 の範囲
//*                     電流時は       0 〜 +8388607 の範囲
//***************************************************************************
DECLSPEC LELanioGetAnalogInput(hLANIO handle, int ch, int *val);

//***************************************************************************
//*全chのアナログ入力の現在値をADC値で取得します。
//*引数   : handle    LANIO操作ハンドル
//*         count     取得するAIポート数の最大値 (2の場合 AI2までを取得)
//*         val       ADC 値を取得する配列
//*                   現在の入力レンジが
//*                     電圧時は-8388608 〜 +8388607 の範囲
//*                     電流時は       0 〜 +8388607 の範囲
//***************************************************************************
DECLSPEC LELanioGetAnalogInputAll(hLANIO handle, int count, int *val);

//***************************************************************************
//*アナログ入力の現在値を入力レンジ設定状態と共に実値で取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         range     入力レンジを取得するポインタ
//*                   0:+-100mV   1:+-1V     2:+-10V    3:+-30V
//*                   4:0-20mA(250ohm)  5:0-20mA(50ohm) 6:熱電対
//*         val       測定値を取得する変数のポインタ
//*                   現在の入力レンジが
//*                     電圧の場合は V  単位
//*                     電流の場合は mA 単位
//*                     熱電対の場合 摂氏温度
//***************************************************************************
DECLSPEC LELanioGetAnalogInputByValue(hLANIO handle, int ch, int *range, double *val);

//***************************************************************************
//*アナログ入力のレンジ設定を行います
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         range     入力レンジ設定値
//*                   0:+-100mV   1:+-1V     2:+-10V    3:+-30V
//*                   4:0-20mA(250ohm)  5:0-20mA(50ohm) 6:熱電対
//***************************************************************************
DECLSPEC LELanioSetAnalogInputRange(hLANIO handle, int ch, int range);

//***************************************************************************
//*アナログ入力のレンジ設定を取得します
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         range     入力レンジを取得する変数のポインタ
//*                   0:+-100mV   1:+-1V     2:+-10V    3:+-30V
//*                   4:0-20mA(250ohm)  5:0-20mA(50ohm) 6:熱電対
//***************************************************************************
DECLSPEC LELanioGetAnalogInputRange(hLANIO handle, int ch, int *range);

//***************************************************************************
//*アナログ入力の内蔵ADC sps設定を行います
//*引数   : handle    LANIO操作ハンドル
//*         sps       内蔵ADC サンプリング速度設定値
//*                   0:10sps   1:16.6sps  2:50sps    3:60sps
//*                   4:400sps  5:1200sps  6:3600sps  7:14400sps
//***************************************************************************
DECLSPEC LELanioSetAnalogInputADCsps(hLANIO handle, int sps);


//***************************************************************************
//*アナログ入力の内蔵ADC sps設定を取得します
//*引数   : handle    LANIO操作ハンドル
//*         sps       内蔵ADC サンプリング速度設定値を取得する変数のポインタ
//*                   0:10sps   1:16.6sps  2:50sps    3:60sps
//*                   4:400sps  5:1200sps  6:3600sps  7:14400sps
//***************************************************************************
DECLSPEC LELanioGetAnalogInputADCsps(hLANIO handle, int *sps);

//***************************************************************************
//*アナログ入出力モデルのアナログ閾値設定を行います。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI/AO ポートの指定(AI1/AO1 = 0, AI2/AO2 = 1, ...)
//*         led       LED点灯方向  0:範囲内で点灯  1:範囲外で点灯
//*         th_L      下側閾値 -32768から32767の範囲 (DAC内部値又はADC内部値の上位16bit)
//*         th_H      上側閾値 -32768から32767の範囲 (DAC内部値又はADC内部値の上位16bit)
//***************************************************************************
DECLSPEC LELanioSetAnalogThresholds(hLANIO handle, int ch, int led, int th_L, int th_H);

//***************************************************************************
//*アナログ入出力モデルのアナログ閾値設定を取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI/AO ポートの指定(AI1/AO1 = 0, AI2/AO2 = 1, ...)
//*         led       LED点灯方向  0:範囲内で点灯  1:範囲外で点灯
//*         th_L      下側閾値 -32768から32767の範囲 (DAC値又はADC値の上位16bit)
//*         th_H      上側閾値 -32768から32767の範囲 (DAC値又はADC値の上位16bit)
//***************************************************************************
DECLSPEC LELanioGetAnalogThresholds(hLANIO handle, int ch, int *led, int *th_L, int *th_H);

//***************************************************************************
//*アナログ入力モデルのアナログ値転送周期を設定します。
//*引数   : handle    LANIO操作ハンドル
//*         cycle     周期転送周期
//*                   0:50ms   1:100ms  2:200ms  3:500ms  4:1sec
//*                   5:2sec   6:5sec   7:10sec  8:20sec  9:30sec
//*                   10:1min  11:2min  12:5min  13:10min 
//***************************************************************************
DECLSPEC LELanioSetAiTransmitCycle(hLANIO handle, int cycle);

//***************************************************************************
//*アナログ入力モデルのアナログ値転送周期を取得します。
//*引数   : handle    LANIO操作ハンドル
//*         cycle     周期転送周期を取得する変数のポインタ
//*                   0:50ms   1:100ms  2:200ms  3:500ms  4:1sec
//*                   5:2sec   6:5sec   7:10sec  8:20sec  9:30sec
//*                   10:1min  11:2min  12:5min  13:10min 
//***************************************************************************
DECLSPEC LELanioGetAiTransmitCycle(hLANIO handle, int *cycle);

//***************************************************************************
//*アナログ入力モデルの熱電対タイプ等の温度測定設定を行います。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         tctype    熱電対タイプ
//*                   0:Kタイプ  1:Jタイプ  2:Tタイプ  3:Eタイプ
//*                   4:Nタイプ  5:Rタイプ  6:Sタイプ  7:Bタイプ
//*         cj        冷接点補償のON/OFF
//*                   0:無効     1:有効(デフォルト)
//*         bodet     断線検知機能のON/OFF
//*                   0:無効     1:有効(デフォルト)
//*         boval     断線を検知した場合の値の設定
//*                   0:最低値(0x800000 = -3276.8度相当) (デフォルト)
//*                   1:最高値(0x7FFFFF = +3276.8度相当)
//**************************************************************************
DECLSPEC LELanioSetTCConfig(hLANIO handle, int ch, int tctype, int cj, int bodet, int boval);

//***************************************************************************
//*アナログ入力モデルの熱電対タイプの設定を行います。
//*通常変更する必要のない冷接点補償,断線検知,断線検知時の値は
//*デフォルト値で上書きされます。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         tctype    熱電対タイプ
//*                   0:Kタイプ  1:Jタイプ  2:Tタイプ  3:Eタイプ
//*                   4:Nタイプ  5:Rタイプ  6:Sタイプ  7:Bタイプ
//**************************************************************************
DECLSPEC LELanioSetTCType(hLANIO handle, int ch, int tctype);

//***************************************************************************
//*アナログ入力モデルの熱電対タイプ等の温度測定設定を取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         tctype    熱電対タイプを取得する変数のポインタ
//*                   0:Kタイプ  1:Jタイプ  2:Tタイプ  3:Eタイプ
//*                   4:Nタイプ  5:Rタイプ  6:Sタイプ  7:Bタイプ
//*         cj        冷接点補償のON/OFFを取得する変数のポインタ
//*                   0:無効     1:有効(デフォルト)
//*         bodet     断線検知機能のON/OFFを取得する変数のポインタ
//*                   0:無効     1:有効(デフォルト)
//*         boval     断線を検知した場合の値の設定を取得する変数のポインタ
//*                   0:最低値(0x800000 = -3276.8度相当) (デフォルト)
//*                   1:最高値(0x7FFFFF = +3276.8度相当)
//**************************************************************************
DECLSPEC LELanioGetTCConfig(hLANIO handle, int ch, int *tctype, int *cj, int *bodet, int *boval);

//***************************************************************************
//*アナログ入力モデルがアナログ出力モデルに温度情報を伝送する際の
//*対向出力レンジとスケールを設定します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         range     対向出力レンジ
//*                   0:0-10V    1:0-5V     1:1-5V     4:4-20mA
//*         scale_L   スケール下限温度 (摂氏温度)
//*         scale_H   スケール上限温度 (摂氏温度)
//**************************************************************************
DECLSPEC LELanioSetTCTransmitScale(hLANIO handle, int ch, int range, double scale_L, double scale_H);

//***************************************************************************
//*アナログ入力モデルがアナログ出力モデルに温度情報を伝送する際の
//*対向出力レンジとスケールを取得します。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         range     対向出力レンジを取得する変数のポインタ
//*                   0:0-10V    1:0-5V     1:1-5V     4:4-20mA
//*         scale_L   スケール下限温度 (摂氏温度)を取得する変数のポインタ
//*         scale_H   スケール上限温度 (摂氏温度)を取得する変数のポインタ
//**************************************************************************
DECLSPEC LELanioGetTCTransmitScale(hLANIO handle, int ch, int *range, double *scale_L, double *scale_H);

//***************************************************************************
//*LA-2R3A(V2)のDOアラート機能の設定をします。
//*閾値は LELanioSetAnalogThresholds で設定したものが使用されます。
//*引数   : handle    LANIO操作ハンドル
//*         ch        操作対象とするDO ポートの指定(DO1 = 0, DO2 = 1)
//*         aiport    判定対象とするAI ポートの指定(AI1 = 0, AI2 = 1, ...)
//*         hydir     ヒステリシスを設定する際の方向設定
//*                   0:OFF閾値優先     1:ON閾値優先
//*         hyst      ヒステリシス幅  0(なし)〜65535(入力レンジ全域)
//**************************************************************************
DECLSPEC LELanioSetDOAlertConfig(hLANIO handle, int ch, int aiport, int hydir, int hyst);

//***************************************************************************
//*LA-2R3A(V2)のDOアラート機能の動作開始/停止を制御します
//*引数   : handle    LANIO操作ハンドル
//*       : ch        対象とするDO ポートの指定(DO1 = 0, DO2 = 1)
//*       : state     0:停止     1:開始
//**************************************************************************
DECLSPEC LELanioDOAlertStartStop(hLANIO handle, int ch, int state);

//***************************************************************************
//*LA-2R3A(V2)のDOアラート機能の設定と動作状態を取得します。
//*閾値は LELanioSetAnalogThresholds で設定したものが使用されます。
//*引数   : handle    LANIO操作ハンドル
//*         ch        対象DO ポート(DO1 = 0, DO2 = 1)の指定
//*         state     動作状態  0:停止中  1:動作中
//*         aiport    判定対象AI ポート(AI1 = 0, AI2 = 1, ...)
//*         hydir     ヒステリシスを設定する際の方向
//*                   0:OFF閾値優先     1:ON閾値優先
//*         hyst      ヒステリシス幅  0(なし)〜65535(入力レンジ全域)
//**************************************************************************
DECLSPEC LELanioGetDOAlertStatus(hLANIO handle, int ch, int *state, int *aiport, int *hydir, int *hyst);

//***************************************************************************
//*アナログ入力モデルのAIメールアラート機能の設定をします。
//*閾値は LELanioSetAnalogThresholds で設定したものが使用されます。
//*引数   : handle    LANIO操作ハンドル
//*         ch        設定を行うAI ポート(AI1 = 0, AI2 = 1)の指定
//*         condition メール送信を行う条件の指定
//*                   0:送信しない   1:LED点灯時   2:LED消灯時
//**************************************************************************
DECLSPEC LELanioSetAiMailCondition(hLANIO handle, int ch, int condition);

//***************************************************************************
//*アナログ入力モデルのAIメールアラート機能の設定を確認します。
//*閾値は LELanioSetAnalogThresholds で設定したものが使用されます。
//*引数   : handle    LANIO操作ハンドル
//*         ch        設定を取得するAI ポート(AI1 = 0, AI2 = 1)の指定
//*         condition メール送信を行う条件を取得する変数のポインタ
//*                   0:送信しない   1:LED点灯時   2:LED消灯時
//**************************************************************************
DECLSPEC LELanioGetAiMailCondition(hLANIO handle, int ch, int *condition);
