#include <stdio.h>
#include <unistd.h>
#include "LELanio.h"

#define RUN_SEC 30 // 30秒テストする

/*******************************************************/
/* ポーリング動作簡易確認サンプル                      */
/*                                                     */
/* 引数 : LANIOのIPアドレス                            */
/*******************************************************/

/* DI の数をモデルIDから判別 */
static int getNumDI(enum LANIOMODEL model){
	switch(model){
	default:
		return 0;
	case LA3R2P:
	case LA5T2S:
	case LA232R:
	case LA232T:
	case LA485R:
	case LA485T:
	case LA3A2PP:
	case LAN2R2P:
		return 2;
	case LA2R3PP:
	case LA3R3PP:
	case LA2R3A:   // DIの代わりにAIのLED点灯状態を取得
	case LA2R3AV2: // DIの代わりにAIのLED点灯状態を取得
	case LA2A3PP:
		return 3;
	case LA4R4PP:
	case LA4T4SP:
		return 4;
	case LA5PP:
	case LA5AI:    // DIの代わりにAIのLED点灯状態を取得
		return 5;
	case LA7P:
		return 7;
	case LA8PP:
		return 8;
	}
}

static void PrintHeader(int n_di){
	int i;
	printf("\n\n DI:");
	for(i=0; i<n_di; i++){
		printf(" %3d", i+1);	   
	}
	printf("\n");			
}

static void PrintResult(int iSec, int n_di, int inpio){
	int i;
	printf("\r    "); // 改行せず上書き
	for(i=0; i<n_di; i++){
		if(((inpio >> i) & 0x1 ) != 0){
			printf("   X"); 
		}
		else{
			printf("   -");
		}
	}
	printf("  %3d/%3d cycle  ", iSec+1, RUN_SEC);
	fflush(stdout);
}


int main(int argc, char *argv[]){
	int i;
	int ret;
	int err;
	hLANIO handle;
	int id;
	int n_di;
	int di_bits;
	enum LANIOMODEL eModel;

	/* 引数の確認 */
	if(argc != 2){
		printf("usage : %s IPaddress\n", argv[0]);
		return -1;
	}

	/* ライブラリの初期化 */
	ret = LELanioInit();
	if(!ret){
		printf("Error : LELanioInit() : %d\n", LELanioGetLastError());
		return -1;
	}

	/* 検索を省略して IPアドレス指定で接続 */
	printf("Connecting to %s ...\n", argv[1]);
	handle = LELanioConnectDirect(argv[1], 1000); // timeout 1sec
	if(handle < 0){
		printf("Error : LELanioConnectDirect() : %d\n", LELanioGetLastError());
		return -1;
	}

	err = 0;

	/* 入力ch があるモデルで、なおかつ入力延長動作中でないことを確認 */
	ret = LELanioRequestIdModel(handle, &id, &eModel);
	if(!ret){
		err = LELanioGetLastError();
		printf("Error : LELanioRequestIdModel() : %d\n", err);
		goto END;
	}
	n_di = getNumDI(eModel);
	if(n_di == 0){
		printf("Model Error : The LANIO has no input channels\n");
		goto END;
	}
	if(id == 0xF){
		printf("ID Error : The LANIO is in F-mode\n");
		goto END;
	}
	
	PrintHeader(n_di);

	/* 1秒間隔で すべてのDI の入力状態をPolling して表示 */
	/* X : ON   - : OFF           */
	for(i=0; i<RUN_SEC; i++){
		sleep(1);
		ret = LELanioInPioAll(handle, &di_bits);
		if(!ret){
			err = LELanioGetLastError();
			printf("\n\nError : LELanioInPioAll() : %d\n", err);
			break;
		}

		PrintResult(i, n_di, di_bits);
	}

 END:
	printf("\n\n");
	printf("Closing connection...\n");
	LELanioClose(handle);
	printf("End.\n");
	LELanioEnd();
	return err;	
}
